Skip to contents

Identify gene modules within each cell cluster

Usage

ctsvg_module(clutestRes, clufitRes, sc, seed = 2024, clunum = NULL)

Arguments

clutestRes

The output from ctsvg_test

clufitRes

The output from ctsvg_fit

sc

The named vector of cell cluster assignments

seed

Random seed for k-means clustering (2024 by default)

clunum

Number of modules (NULL by default, automatically selected)

Value

A list with each element representing a cell cluster and indicating which module each gene belongs to