Assign each square to a cell
Usage
cellassign(visiumpath, segmentationpath, cellnucratio = 2)
Arguments
- visiumpath
The path to the Visium HD output folder
- segmentationpath
The path to the StarDist segmentation file
- cellnucratio
The ratio of cell size and nucleus size (2 by default)
Value
A list including a vector indicating which cell each square belongs to, and the matrix of spatial locations