Fit spatial gene expression patterns within each cell cluster
Usage
ctsvg_fit(expr, coord, sc, cell.filter = TRUE)
Arguments
- expr
The normalized gene expression matrix
- coord
The matrix of spatial locations
- sc
The named vector of cell cluster assignments
- cell.filter
Whether to remove spatially isolated cells within each cell cluster (TRUE by default)
Value
The fitted cell-cluster-specific gene expression matrix