Visualize spatial patterns of metagenes within a cell cluster
Arguments
- clufitRes
The output from
ctsvg_fit- coord
The matrix of spatial locations
- sc
The named vector of cell cluster assignments
- moduleRes
The output from
ctsvg_module- cellclu
A character value indicating which cell cluster to plot
- background
Whether to plot all cells (
FALSEby default)- ...
The parameters in the
geom_point(...)function