Run Seurat pipeline
Arguments
- count
The output from
getexpr- min.genes
The minimum number of genes that are expressed in a cell for it to be retained (300 by default)
- min.cells
The minimum proportion of cells a gene is expressed in to be retained (0.01 by default)
- npcs
Number of PCs to use (10 by default)
- resolution
The parameter in the
FindClustersfunction (1.2 by default)